<div id="top"></div>

<div align="center">
  <a href="https://github.com/Clouder0/AIOB">
    <img src="logo.jpg" alt="Logo">
  </a>

<h3 align="center">AIOB</h3>
  <p align="center">
    All In One Bridge for your Datas
    <br />
    <a href="https://github.com/Clouder0/AIOB"><strong>Explore the docs »</strong></a>
  </p>
</div>

## 📜 TOC

<details>
  <summary>Table of Contents</summary>

- [🌟 Badges](#🌟-badges)
- [💡 Introduction](#💡-introduction)
- [✨ Features](#✨-features)
- [🎏 Getting Started](#🎏-getting-started)
- [🗺️ Roadmap](#🗺️-roadmap)
- [❓ Faq](#❓-faq)
- [💌 Contributing](#💌-contributing)
- [🙏 Acknowledgment](#🙏-acknowledgment)
- [📖 License](#📖-license)
- [📧 Contact](#📧-contact)

</details>

## 🌟 Badges

[![Test][github-action-test-shield]][github-action-test-url]
[![Codecov][codecov-shield]][codecov-url]
[![pre-commit-ci][pre-commit-ci-shield]][pre-commit-ci-url]
[![pepy-shield]][pepy-url]

[![release-shield]][release-url]
[![pyversions-shield]][pyversions-url]
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![Apache License 2.0][license-shield]][license-url]
[![CodeFactor-shield]][CodeFactor-url]
[![code-style-black-shield]][code-style-black-url]

<!-- INTRODUCTION -->
## 💡 Introduction

**Unfortunately, AIOB is still under initial development and hasn't been prepared for users.**  
**Several embeded sources/destinations will be added until the very first official release. Salient changes might be made to optimize project structures and so on.**  
**Please wait until version 0.1.0 is published.**  

<p align="right">(<a href="#top">back to top</a>)</p>

<!-- FEATURES -->
## ✨ Features

<p align="right">(<a href="#top">back to top</a>)</p>

<!-- GETTING STARTED -->
## 🎏 Getting Started

<details> <summary>Click Here to Get Started Instantly.</summary>

TODO.

### Installation

<p align="right">(<a href="#top">back to top</a>)</p>

### Command Line Interface

<p align="right">(<a href="#top">back to top</a>)</p>

### Configuration

<p align="right">(<a href="#top">back to top</a>)</p>

### Plugin System

<p align="right">(<a href="#top">back to top</a>)</p>

</details>

<!-- ROADMAP -->
## 🗺️ Roadmap

Please check out our [Github Project](https://github.com/users/Clouder0/projects/2).

See the [open issues](https://github.com/Clouder0/AIOB/issues) for a full list of proposed features (and known issues).

<p align="right">(<a href="#top">back to top</a>)</p>

<!-- FAQ -->
## ❓ FAQ

<p align="right">(<a href="#top">back to top</a>)</p>

<!-- CONTRIBUTING -->
## 💌 Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

Don't forget to see our [Contributing Guideline](https://github.com/Clouder0/AIOB/blob/main/CONTRIBUTING.md) for details.

<p align="right">(<a href="#top">back to top</a>)</p>

## 🙏 Acknowledgment

There are various open source projects that AIOB depends on, without which this tool wouldn't exist. Credits to them!

<details> <summary>List</summary>

- [tinydb](https://github.com/msiemens/tinydb), MIT License
- [Dynaconf](https://github.com/rochacbruno/dynaconf), MIT License
- [aiofiles](https://github.com/Tinche/aiofiles), Apache License 2.0
- [python-frontmatter](https://github.com/eyeseast/python-frontmatter), MIT License
- [typer](https://github.com/tiangolo/typer), MIT License
- [aiohttp](https://github.com/aio-libs/aiohttp), Apache License 2.0
- [importlib_metadata](https://github.com/python/importlib_metadata), Apache License 2.0

</details>

<p align="right">(<a href="#top">back to top</a>)</p>

## 📖 License

Distributed under the Apache License 2.0. See `LICENSE` for more information.

<p align="right">(<a href="#top">back to top</a>)</p>

## 📧 Contact

Clouder0's email: clouder0@outlook.com

Project Link: [https://github.com/Clouder0/AIOB](https://github.com/Clouder0/AIOB)

<p align="right">(<a href="#top">back to top</a>)</p>

<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[contributors-shield]: https://img.shields.io/github/contributors/Clouder0/AIOB.svg?style=for-the-badge
[contributors-url]: https://github.com/Clouder0/AIOB/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/Clouder0/AIOB.svg?style=for-the-badge
[forks-url]: https://github.com/Clouder0/AIOB/network/members
[stars-shield]: https://img.shields.io/github/stars/Clouder0/AIOB.svg?style=for-the-badge
[stars-url]: https://github.com/Clouder0/AIOB/stargazers
[issues-shield]: https://img.shields.io/github/issues/Clouder0/AIOB.svg?style=for-the-badge
[issues-url]: https://github.com/Clouder0/AIOB/issues
[license-shield]: https://img.shields.io/github/license/Clouder0/AIOB.svg?style=for-the-badge
[license-url]: https://github.com/Clouder0/AIOB/blob/main/LICENSE
[github-action-test-shield]: https://github.com/Clouder0/AIOB/actions/workflows/test.yml/badge.svg?branch=main
[github-action-test-url]: https://github.com/Clouder0/AIOB/actions/workflows/test.yml
[codecov-shield]:https://codecov.io/gh/Clouder0/AIOB/branch/main/graph/badge.svg?token=D2XT099AFB
[codecov-url]: https://codecov.io/gh/Clouder0/AIOB
[pre-commit-ci-shield]: https://results.pre-commit.ci/badge/github/Clouder0/AIOB/main.svg
[pre-commit-ci-url]: https://results.pre-commit.ci/latest/github/Clouder0/AIOB/main
[code-style-black-shield]: https://img.shields.io/badge/code%20style-black-000000.svg?style=for-the-badge
[code-style-black-url]: https://github.com/psf/black
[pyversions-shield]: https://img.shields.io/pypi/pyversions/aiob.svg?style=for-the-badge
[pyversions-url]: https://pypi.org/project/aiob/
[release-shield]: https://img.shields.io/github/release/Clouder0/AIOB.svg?style=for-the-badge
[release-url]: https://github.com/Clouder0/AIOB/releases
[CodeFactor-shield]: https://www.codefactor.io/repository/github/clouder0/aiob/badge/main?style=for-the-badge
[CodeFactor-url]: https://www.codefactor.io/repository/github/clouder0/aiob/overview/main
[pepy-shield]: https://static.pepy.tech/personalized-badge/aiob?period=total&units=international_system&left_color=grey&right_color=brightgreen&left_text=Downloads
[pepy-url]: https://pepy.tech/project/aiob
